==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1beta1CSINodeDriverFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1beta1CSINodeDriverFluent<A extends V1beta1CSINodeDriverFluent<A>> extends Fluent<A>{


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getNodeID();
    public A withNodeID(String nodeID);
    public Boolean hasNodeID();
    public A withNewNodeID(String arg1);
    public A withNewNodeID(StringBuilder arg1);
    public A withNewNodeID(StringBuffer arg1);
    public A addToTopologyKeys(int index,String item);
    public A setToTopologyKeys(int index,String item);
    public A addToTopologyKeys(String... items);
    public A addAllToTopologyKeys(Collection<String> items);
    public A removeFromTopologyKeys(String... items);
    public A removeAllFromTopologyKeys(Collection<String> items);
    public List<String> getTopologyKeys();
    public String getTopologyKey(int index);
    public String getFirstTopologyKey();
    public String getLastTopologyKey();
    public String getMatchingTopologyKey(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingTopologyKey(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withTopologyKeys(List<String> topologyKeys);
    public A withTopologyKeys(String... topologyKeys);
    public Boolean hasTopologyKeys();
    public A addNewTopologyKey(String arg1);
    public A addNewTopologyKey(StringBuilder arg1);
    public A addNewTopologyKey(StringBuffer arg1);



}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/V1beta1CSINodeDriverFluent.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1CSINodeDriverFluent<A extends V1beta1CSINodeDriverFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAllocatable instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1VolumeNodeResources getAllocatable();
    public V1beta1VolumeNodeResources buildAllocatable();
    public A withAllocatable(V1beta1VolumeNodeResources allocatable);
    public Boolean hasAllocatable();
    public V1beta1CSINodeDriverFluent.AllocatableNested<A> withNewAllocatable();
    public V1beta1CSINodeDriverFluent.AllocatableNested<A> withNewAllocatableLike(V1beta1VolumeNodeResources item);
    public V1beta1CSINodeDriverFluent.AllocatableNested<A> editAllocatable();
    public V1beta1CSINodeDriverFluent.AllocatableNested<A> editOrNewAllocatable();
    public V1beta1CSINodeDriverFluent.AllocatableNested<A> editOrNewAllocatableLike(V1beta1VolumeNodeResources item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getNodeID();
    public A withNodeID(String nodeID);
    public Boolean hasNodeID();
    public A withNewNodeID(String arg1);
    public A withNewNodeID(StringBuilder arg1);
    public A withNewNodeID(StringBuffer arg1);
    public A addToTopologyKeys(int index,String item);
    public A setToTopologyKeys(int index,String item);
    public A addToTopologyKeys(String... items);
    public A addAllToTopologyKeys(Collection<String> items);
    public A removeFromTopologyKeys(String... items);
    public A removeAllFromTopologyKeys(Collection<String> items);
    public List<String> getTopologyKeys();
    public String getTopologyKey(int index);
    public String getFirstTopologyKey();
    public String getLastTopologyKey();
    public String getMatchingTopologyKey(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingTopologyKey(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withTopologyKeys(List<String> topologyKeys);
    public A withTopologyKeys(String... topologyKeys);
    public Boolean hasTopologyKeys();
    public A addNewTopologyKey(String arg1);
    public A addNewTopologyKey(StringBuilder arg1);
    public A addNewTopologyKey(StringBuffer arg1);

    public interface AllocatableNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1VolumeNodeResourcesFluent<V1beta1CSINodeDriverFluent.AllocatableNested<N>>{

        
    public N and();    public N endAllocatable();
}


}
